indexing

	description:

		"Adapter writing to a Gobo output stream."

	library: "Gobo Eiffel Pipework Library"
	copyright: "Copyright (c) 2002, Simon Parker and others"
	license: "Eiffel Forum License v1 (see forum.txt)"
	date: "$Date: $"
	revision: "$Revision: $"

class

	PW_OUTPUT_STREAM [INWARD]

inherit

	PW_WRITER [INWARD]

creation

	make,
	connect

feature -- Initialization

	make is
			-- Create or reset the adapter.
		do
			if is_connected then
				disconnect
			end
		ensure then
			not_connected: not is_connected
		end

feature -- Status

	is_connected: BOOLEAN is
			-- Is there a file?
		do
			Result := drain /= Void
		end

feature -- Connection

	drain: KI_OUTPUT_STREAM [INWARD]
			-- The destination

	connect (outlet: like drain) is
			-- Establish a (new) drain.
			-- Disconnect first, if necessary.
		do
			if is_connected then
				disconnect
			end
			drain := outlet
		ensure
			drain_installed: drain = outlet
			connected: is_connected
		end

	disconnect is
			-- Flush myself,
			-- then disconnect from current drain.
		require
			connected: is_connected
		do
			drain := Void
		ensure
			disconnected: not is_connected
		end

	reconnect (outlet: like drain) is
			-- Disconnect, then connect.
		require
			connected: is_connected
		do
			disconnect
			connect (outlet)
		ensure
			is_connected: is_connected
		end

feature -- Writing

	put (p_item: INWARD) is
			-- Write item as-is to current position in file.
		do
			if is_connected then
				if p_item /= Void then
					drain.put (p_item)
				end
			end
		end


invariant

	outlet_writable: is_connected implies drain.is_open_write

end
