indexing

	description:

		"Adapter for writing a STRING to a Gobo character output stream."

	implementation:
		"We cannot inherit from KI_OUTPUT_STREAM, because %
		%KI_CHARACTER_OUTPUT_STREAM is not a KI_OUTPUT_STREAM [STRING]."

	library: "Gobo Eiffel Pipework Library"
	copyright: "Copyright (c) 2003, Simon Parker and others"
	license: "Eiffel Forum License v2 (see forum.txt)"
	date: "$Date: $"
	revision: "$Revision: $"

class

	PW_STRING_OUTPUT_STREAM

inherit

	PW_WRITER [STRING]
		redefine
			flush
		end

creation

	make,
	connect

feature -- Initialization

	make is
			-- Create or reset the adapter.
		do
			if is_connected then
				disconnect
			end
		ensure then
			not_connected: not is_connected
		end

feature -- Status

	is_connected: BOOLEAN is
			-- Is there a file?
		do
			Result := drain /= Void
		end

feature -- Connection

	drain: KI_CHARACTER_OUTPUT_STREAM
			-- The destination

	connect (outlet: like drain) is
			-- Establish a (new) drain.
			-- Disconnect first, if necessary.
		do
			if is_connected then
				disconnect
			end
			drain := outlet
		ensure
			drain_installed: drain = outlet
			connected: is_connected
		end

	disconnect is
			-- Flush myself,
			-- then disconnect from current drain.
		require
			connected: is_connected
		do
			drain := Void
		ensure
			disconnected: not is_connected
		end

	reconnect (outlet: like drain) is
			-- Disconnect, then connect.
		require
			connected: is_connected
		do
			disconnect
			connect (outlet)
		ensure
			is_connected: is_connected
		end

feature -- Writing

	flush is
			-- Empty any buffered items.
		do
			drain.close
		end

	put (p_item: STRING) is
			-- Write item at current position in file,
			-- followed by line-end.
		do
			if is_connected then
				if p_item /= Void then
					drain.put_string (p_item)
				end
			end
		end

end
